#ifndef EFL_UI_BOX_FLOW_IMPL_HH
#define EFL_UI_BOX_FLOW_IMPL_HH

#include "efl_ui_box_flow.eo.hh"

namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<bool>::type Box_Flow::box_flow_homogenous_get() const
{
   Eina_Bool __return_value =  ::efl_ui_box_flow_homogenous_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Box_Flow::box_flow_homogenous_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_ui_box_flow_homogenous_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
inline ::efl::eolian::return_traits<bool>::type Box_Flow::box_flow_max_size_get() const
{
   Eina_Bool __return_value =  ::efl_ui_box_flow_max_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Box_Flow::box_flow_max_size_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_ui_box_flow_max_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<bool>::type Box_Flow::box_flow_homogenous_get() const
{
   Eina_Bool __return_value =  ::efl_ui_box_flow_homogenous_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Box_Flow::box_flow_homogenous_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_ui_box_flow_homogenous_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
inline ::efl::eolian::return_traits<bool>::type Box_Flow::box_flow_max_size_get() const
{
   Eina_Bool __return_value =  ::efl_ui_box_flow_max_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Box_Flow::box_flow_max_size_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_ui_box_flow_max_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
inline efl::ui::Box_Flow::operator ::efl::ui::Box_Flow() const { return *static_cast< ::efl::ui::Box_Flow const*>(static_cast<void const*>(this)); }
inline efl::ui::Box_Flow::operator ::efl::ui::Box_Flow&() { return *static_cast< ::efl::ui::Box_Flow*>(static_cast<void*>(this)); }
inline efl::ui::Box_Flow::operator ::efl::ui::Box_Flow const&() const { return *static_cast< ::efl::ui::Box_Flow const*>(static_cast<void const*>(this)); }
} } }
#endif
